Descriptor of an AnvlGraph. This is a mutable class.
Arguments
- calls
(
list(PrimitiveCall))
The primitive calls that make up the graph.- tensor_to_gval
(
hashtab)
Mapping:AnvlArray->GraphValue- gval_to_box
(
hashtab)
Mapping:GraphValue->GraphBox- constants
(
list(GraphValue))
The constants of the graph.- in_tree
(
NULL | Node)
The tree of inputs. May contain leaves for both array inputs and static (non-array) arguments. Only the array leaves correspond to entries ininputs; useis_static_flatto distinguish them.- out_tree
(
NULL | Node)
The tree of outputs.- inputs
(
list(GraphValue))
The inputs to the graph (array arguments only).- outputs
(
list(GraphValue))
The outputs of the graph.- is_static_flat
(
NULL | logical())
Boolean mask indicating which flat positions inin_treeare static (non-array) args.NULLwhen all args are array inputs.- static_args_flat
(
NULL | list())
Flattened traced values for the static arguments indicated byis_static_flat.- devices
(
character())
Device platforms encountered during tracing (e.g."cpu","cuda"). Populated automatically as arrays are registered.