Skip to contents

Constructs a Shape, the axis sizes of an array. A Shape is its integer vector, with a class attached, so length() is the number of axes and shape[i] is the size of axis i.

Usage

Shape(dims = integer())

Arguments

dims

An integer() vector of axis sizes (>= 0). NA marks an axis whose size is only known at run time.

Value

(Shape)

Examples

Shape(c(2L, 3L))
#> (2x3)