Skip to contents

The shape of an array, i.e. its axis sizes – the generic base::dim() on an anvl array, and the same thing as shape().

Unlike base R, it also has a value for an array with a single axis, where dim() on an R vector is NULL.

Usage

# S3 method for class 'AnvlArray'
dim(x)

Arguments

x

(arrayish)
Input array.

Value

(integer())

See also

Examples

dim(nv_matrix(1:6, nrow = 2))
#> [1] 2 3
dim(nv_array(1:3))
#> [1] 3