Element-wise absolute value. You can also use abs().
Arguments
- operand
(
arrayish)
Operand.
Value
arrayish
Has the same shape and data type as the input.
See also
prim_abs() for the underlying primitive.
Element-wise absolute value. You can also use abs().
(arrayish)
Operand.
arrayish
Has the same shape and data type as the input.
prim_abs() for the underlying primitive.