Element-wise inverse cosine. You can also use acos().
Arguments
- operand
(
arrayish)
Operand.
Value
arrayish
Has the same shape and data type as the input.
See also
prim_acos() for the underlying primitive.
Element-wise inverse cosine. You can also use acos().
(arrayish)
Operand.
arrayish
Has the same shape and data type as the input.
prim_acos() for the underlying primitive.