Element-wise inverse hyperbolic cosine. You can also use acosh().
Arguments
- operand
(
arrayish)
Operand.
Value
arrayish
Has the same shape and data type as the input.
See also
prim_acosh() for the underlying primitive.
Element-wise inverse hyperbolic cosine. You can also use acosh().
(arrayish)
Operand.
arrayish
Has the same shape and data type as the input.
prim_acosh() for the underlying primitive.