Element-wise inverse sine. You can also use asin().
Arguments
- operand
(
arrayish)
Operand.
Value
arrayish
Has the same shape and data type as the input.
See also
prim_asin() for the underlying primitive.
Element-wise inverse sine. You can also use asin().
(arrayish)
Operand.
arrayish
Has the same shape and data type as the input.
prim_asin() for the underlying primitive.