Element-wise inverse hyperbolic sine. You can also use asinh().
Arguments
- operand
(
arrayish)
Operand.
Value
arrayish
Has the same shape and data type as the input.
See also
prim_asinh() for the underlying primitive.
Element-wise inverse hyperbolic sine. You can also use asinh().
(arrayish)
Operand.
arrayish
Has the same shape and data type as the input.
prim_asinh() for the underlying primitive.