Skip to contents

Element-wise cube root.

Usage

nv_cbrt(x)

Arguments

x

(arrayish)
One input. Can be any numeric data type: a float keeps its own, and an integer one is converted to the default float data type (see default_dtypes()). An R value materializes at its default data type and is converted in the same way.

Value

(arrayish)
Has the input's shape, and its data type – or the default float data type (see default_dtypes()) where the input was an integer one.

See also

prim_cbrt() for the underlying primitive.

Examples

# the input's data type carries through
x <- nv_array(c(1, 8, 27))
nv_cbrt(x)
#> AnvlArray
#>  1
#>  2
#>  3
#> [ CPUf32{3} ] 

# an R value materializes at its default data type
nv_cbrt(8)
#> AnvlArray
#>  2
#> [ CPUf32{} ]