Element-wise ceiling (round toward positive infinity). You can also use ceiling().
Arguments
- operand
(
arrayish)
Operand.
Value
arrayish
Has the same shape and data type as the input.
See also
prim_ceil() for the underlying primitive.
Element-wise ceiling (round toward positive infinity). You can also use ceiling().
(arrayish)
Operand.
arrayish
Has the same shape and data type as the input.
prim_ceil() for the underlying primitive.