Element-wise hyperbolic cosine. You can also use cosh().
Arguments
- operand
(
arrayish)
Operand.
Value
arrayish
Has the same shape and data type as the input.
See also
prim_cosh() for the underlying primitive.
Element-wise hyperbolic cosine. You can also use cosh().
(arrayish)
Operand.
arrayish
Has the same shape and data type as the input.
prim_cosh() for the underlying primitive.