Element-wise cosine. You can also use cos().
Arguments
- operand
(
arrayish)
Operand.
Value
arrayish
Has the same shape and data type as the input.
See also
prim_cosine() for the underlying primitive.
Element-wise cosine. You can also use cos().
(arrayish)
Operand.
arrayish
Has the same shape and data type as the input.
prim_cosine() for the underlying primitive.