Skip to contents

Element-wise digamma function (logarithmic derivative of the gamma function). You can also use digamma().

Usage

nv_digamma(x)

Arguments

x

(arrayish)
One input. Can be any numeric data type: a float keeps its own, and an integer one is converted to the default float data type (see default_dtypes()). An R value materializes at its default data type and is converted in the same way.

Value

(arrayish)
Has the input's shape, and its data type – or the default float data type (see default_dtypes()) where the input was an integer one.

See also

prim_digamma() for the underlying primitive.

Examples

# the input's data type carries through
x <- nv_array(c(0.5, 1, 2, 5))
digamma(x)
#> AnvlArray
#>  -1.9635
#>  -0.5772
#>   0.4228
#>   1.5061
#> [ CPUf32{4} ] 

# an R value materializes at its default data type
nv_digamma(2)
#> AnvlArray
#>  0.4228
#> [ CPUf32{} ]