Element-wise inverse error function (the inverse of erf on (-1, 1)).
Arguments
- operand
(
arrayish)
Operand.
Value
arrayish
Has the same shape and data type as the input.
See also
prim_erf_inv() for the underlying primitive.
Element-wise inverse error function (the inverse of erf on (-1, 1)).
(arrayish)
Operand.
arrayish
Has the same shape and data type as the input.
prim_erf_inv() for the underlying primitive.