Element-wise exponential. You can also use exp().
Arguments
- operand
(
arrayish)
Operand.
Value
arrayish
Has the same shape and data type as the input.
See also
prim_exp() for the underlying primitive.
Element-wise exponential. You can also use exp().
(arrayish)
Operand.
arrayish
Has the same shape and data type as the input.
prim_exp() for the underlying primitive.