Element-wise floor (round toward negative infinity). You can also use floor().
Arguments
- operand
(
arrayish)
Operand.
Value
arrayish
Has the same shape and data type as the input.
See also
prim_floor() for the underlying primitive.
Element-wise floor (round toward negative infinity). You can also use floor().
(arrayish)
Operand.
arrayish
Has the same shape and data type as the input.
prim_floor() for the underlying primitive.