Skip to contents

Element-wise gamma function. You can also use gamma().

Usage

nv_gamma(x)

Arguments

x

(arrayish)
One input. Can be any numeric data type: a float keeps its own, and an integer one is converted to the default float data type (see default_dtypes()). An R value materializes at its default data type and is converted in the same way.

Value

(arrayish)
Has the input's shape, and its data type – or the default float data type (see default_dtypes()) where the input was an integer one.

See also

nv_lgamma(), which is what the hardware computes.

Examples

gamma(nv_array(c(0.5, 1, 5, -1.5)))
#> AnvlArray
#>   1.7725
#>   1.0000
#>  24.0000
#>   2.3633
#> [ CPUf32{4} ]