Skip to contents

Element-wise greater than or equal comparison. You can also use the >= operator.

Usage

nv_ge(lhs, rhs)

Arguments

lhs, rhs

(arrayish)
Left and right operand. Operands are promoted to a common data type. Scalars are broadcast to the shape of the other operand.

Value

arrayish
Has the same shape as the inputs and boolean data type.

See also

prim_ge() for the underlying primitive.

Examples

x <- nv_array(c(1, 2, 3))
y <- nv_array(c(3, 2, 1))
x >= y
#> AnvlArray
#>  0
#>  1
#>  1
#> [ CPUbool{3} ]