Skip to contents

Element-wise natural logarithm of the absolute value of the gamma function. You can also use lgamma().

Usage

nv_lgamma(operand)

Arguments

operand

(arrayish)
Operand.

Value

arrayish
Has the same shape and data type as the input.

See also

prim_lgamma() for the underlying primitive.

Examples

x <- nv_array(c(0.5, 1, 2, 5))
lgamma(x)
#> AnvlArray
#>  5.7236e-01
#>  4.7684e-07
#>  0.0000e+00
#>  3.1781e+00
#> [ CPUf32{4} ]