Skip to contents

Element-wise natural logarithm. You can also use log().

Usage

nv_log(x)

Arguments

x

(arrayish)
One input. Can be any numeric data type: a float keeps its own, and an integer one is converted to the default float data type (see default_dtypes()). An R value materializes at its default data type and is converted in the same way.

Value

(arrayish)
Has the input's shape, and its data type – or the default float data type (see default_dtypes()) where the input was an integer one.

See also

prim_log() for the underlying primitive.

Examples

# the input's data type carries through
x <- nv_array(c(1, 2.718, 7.389))
log(x)
#> AnvlArray
#>  0.0000
#>  0.9999
#>  2.0000
#> [ CPUf32{3} ] 

# an R value materializes at its default data type
nv_log(2)
#> AnvlArray
#>  0.6931
#> [ CPUf32{} ]