Element-wise logistic sigmoid: 1 / (1 + exp(-x)).
Arguments
- operand
(
arrayish)
Operand.
Value
arrayish
Has the same shape and data type as the input.
See also
prim_logistic() for the underlying primitive.
Element-wise logistic sigmoid: 1 / (1 + exp(-x)).
(arrayish)
Operand.
arrayish
Has the same shape and data type as the input.
prim_logistic() for the underlying primitive.