Multiplies two arrays element-wise. You can also use the * operator.
Arguments
- lhs, rhs
(
arrayish)
Left and right operand. Operands are promoted to a common data type. Scalars are broadcast to the shape of the other operand.
Value
arrayish
Has the same shape and the promoted common data type of the inputs.
See also
prim_mul() for the underlying primitive.