Negates an array element-wise. You can also use the unary - operator.
Arguments
- operand
(
arrayish)
Operand.
Value
arrayish
Has the same shape and data type as the input.
See also
prim_negate() for the underlying primitive.
Negates an array element-wise. You can also use the unary - operator.
(arrayish)
Operand.
arrayish
Has the same shape and data type as the input.
prim_negate() for the underlying primitive.