Element-wise logical NOT. You can also use the ! operator.
Arguments
- operand
(
arrayish)
Operand.
Value
arrayish
Has the same shape and data type as the input.
See also
prim_not() for the underlying primitive.
Element-wise logical NOT. You can also use the ! operator.
(arrayish)
Operand.
arrayish
Has the same shape and data type as the input.
prim_not() for the underlying primitive.