Element-wise population count (number of set bits).
Arguments
- operand
(
arrayish)
Operand.
Value
arrayish
Has the same shape and data type as the input.
See also
prim_popcnt() for the underlying primitive.
Element-wise population count (number of set bits).
(arrayish)
Operand.
arrayish
Has the same shape and data type as the input.
prim_popcnt() for the underlying primitive.