Element-wise remainder.
This differs from base R's %%, use nv_mod()/%% instead.
Arguments
- lhs, rhs
(
arrayish)
Left and right operand. Operands are promoted to a common data type. Scalars are broadcast to the shape of the other operand.
Value
arrayish
Has the same shape and the promoted common data type of the inputs.
See also
nv_mod() for the flooring remainder, prim_remainder() for the
underlying primitive.