Reverses the order of elements along specified dimensions.
Value
arrayish
Has the same shape and data type as operand.
See also
prim_reverse() for the underlying primitive.
Reverses the order of elements along specified dimensions.
arrayish
Has the same shape and data type as operand.
prim_reverse() for the underlying primitive.