Element-wise reciprocal square root, i.e. 1 / sqrt(x).
Arguments
- operand
(
arrayish)
Operand.
Value
arrayish
Has the same shape and data type as the input.
See also
prim_rsqrt() for the underlying primitive.
Element-wise reciprocal square root, i.e. 1 / sqrt(x).
(arrayish)
Operand.
arrayish
Has the same shape and data type as the input.
prim_rsqrt() for the underlying primitive.