Element-wise sign function. You can also use sign().
Arguments
- operand
(
arrayish)
Operand.
Value
arrayish
Has the same shape and data type as the input.
See also
prim_sign() for the underlying primitive.
Element-wise sign function. You can also use sign().
(arrayish)
Operand.
arrayish
Has the same shape and data type as the input.
prim_sign() for the underlying primitive.