Element-wise sine. You can also use sin().
Arguments
- operand
(
arrayish)
Operand.
Value
arrayish
Has the same shape and data type as the input.
See also
prim_sine() for the underlying primitive.
Element-wise sine. You can also use sin().
(arrayish)
Operand.
arrayish
Has the same shape and data type as the input.
prim_sine() for the underlying primitive.