Removes dimensions of size 1 from an array.
Value
arrayish
Has the same data type as operand with the specified dimensions removed.
Removes dimensions of size 1 from an array.
arrayish
Has the same data type as operand with the specified dimensions removed.