Element-wise hyperbolic tangent. You can also use tanh().
Arguments
- operand
(
arrayish)
Operand.
Value
arrayish
Has the same shape and data type as the input.
See also
prim_tanh() for the underlying primitive.
Element-wise hyperbolic tangent. You can also use tanh().
(arrayish)
Operand.
arrayish
Has the same shape and data type as the input.
prim_tanh() for the underlying primitive.