Skip to contents

Element-wise inverse hyperbolic cosine.

Usage

prim_acosh(x)

Arguments

x

(arrayish)
One input. Can be any float data type. An R value materializes at its default data type.

Value

(arrayish)
Has the input's shape and data type.

Implemented Rules

  • stablehlo

  • reverse

StableHLO

Lowers to hlo_acosh(), an op of the CHLO dialect, a higher-level companion to StableHLO that is lowered to it during compilation. See chlo.acosh.

See also

Examples

# the input's data type carries through
x <- nv_array(c(1, 2, 10))
prim_acosh(x)
#> AnvlArray
#>  0.0000
#>  1.3170
#>  2.9932
#> [ CPUf32{3} ] 

# an R value materializes at its default data type
prim_acosh(2)
#> AnvlArray
#>  1.3170
#> [ CPUf32{} ]