Concatenates arrays along a dimension.
Arguments
- ...
(
arrayish)
Arrays to concatenate. Must all have the same data type, ndims, and shape except alongdimension.- dimension
(
integer(1))
Dimension along which to concatenate (1-indexed).
Value
arrayish
Has the same data type as the inputs.
The output shape matches the inputs in all dimensions except dimension,
which is the sum of the input sizes along that dimension.
It is ambiguous if all inputs are ambiguous.
StableHLO
Lowers to stablehlo::hlo_concatenate().