Skip to contents

Element-wise hyperbolic cosine.

Usage

prim_cosh(x)

Arguments

x

(arrayish)
One input. Can be any float data type. An R value materializes at its default data type.

Value

(arrayish)
Has the input's shape and data type.

Implemented Rules

  • stablehlo

  • reverse

StableHLO

Lowers to hlo_cosh(), an op of the CHLO dialect, a higher-level companion to StableHLO that is lowered to it during compilation. See chlo.cosh.

See also

Examples

# the input's data type carries through
x <- nv_array(c(-1, 0, 1))
prim_cosh(x)
#> AnvlArray
#>  1.5431
#>  1.0000
#>  1.5431
#> [ CPUf32{3} ] 

# an R value materializes at its default data type
prim_cosh(1)
#> AnvlArray
#>  1.5431
#> [ CPUf32{} ]