Computes the eigendecomposition of a symmetric matrix x of
shape (n, n):
$$A = \mathrm{vectors} \, \mathrm{diag}(\mathrm{values}) \,
\mathrm{vectors}^\top.$$
Only the lower triangle of x is read. The columns of vectors
are the (orthonormal) eigenvectors and values is the length-n
vector of (real) eigenvalues in ascending order. Output names and
order match base::eigen().
Arguments
- x
(
arrayish)
One input, a symmetric square matrix with exactly 2 axes. Can be any float data type. An R value materializes at its default data type.
Value
(named list of two arrayish)
Elements values (length n) and vectors
(shape (n, n)). Both have the input's data type.
StableHLO
Lowers to hlo_custom_call() with target "eigh".