Skip to contents

Element-wise equality comparison.

Usage

prim_eq(lhs, rhs)

Arguments

lhs, rhs

(arrayish)
Two inputs of the same data type and shape. Can be any data type. R values assume the other operand's data type when it is in their data type category, and their default data type when neither operand has one.

Value

(arrayish)
Has the inputs' shape and boolean data type.

Implemented Rules

  • stablehlo

  • quickr

  • reverse

StableHLO

Lowers to hlo_compare(), specified under compare. The comparison direction is EQ.

See also

Examples

# two R values: both take an R double's default data type
prim_eq(1, 1)
#> AnvlArray
#>  1
#> [ CPUbool{} ] 

# the R value is built at the array's data type instead
prim_eq(1, nv_scalar(1, "f64"))
#> AnvlArray
#>  1
#> [ CPUbool{} ]