Reverses the order of elements along specified dimensions.
Value
arrayish
Has the same data type and shape as operand.
It is ambiguous if the input is ambiguous.
StableHLO
Lowers to stablehlo::hlo_reverse().
Reverses the order of elements along specified dimensions.
arrayish
Has the same data type and shape as operand.
It is ambiguous if the input is ambiguous.
Lowers to stablehlo::hlo_reverse().