Element-wise left bit shift.
Arguments
- lhs, rhs
(
arrayish)
Arrayish values of data type boolean, integer, or unsigned integer. Must have the same shape.
Value
arrayish
Has the same shape and data type as the inputs.
It is ambiguous if both inputs are ambiguous.
StableHLO
Lowers to stablehlo::hlo_shift_left().