Skip to contents

Element-wise hyperbolic sine.

Usage

prim_sinh(x)

Arguments

x

(arrayish)
One input. Can be any float data type. An R value materializes at its default data type.

Value

(arrayish)
Has the input's shape and data type.

Implemented Rules

  • stablehlo

  • reverse

StableHLO

Lowers to hlo_sinh(), an op of the CHLO dialect, a higher-level companion to StableHLO that is lowered to it during compilation. See chlo.sinh.

See also

Examples

# the input's data type carries through
x <- nv_array(c(-1, 0, 1))
prim_sinh(x)
#> AnvlArray
#>  -1.1752
#>   0.0000
#>   1.1752
#> [ CPUf32{3} ] 

# an R value materializes at its default data type
prim_sinh(1)
#> AnvlArray
#>  1.1752
#> [ CPUf32{} ]