Element-wise tangent.
Arguments
- operand
(
arrayish)
Arrayish value of data type floating-point.
Value
arrayish
Has the same shape and data type as the input.
It is ambiguous if the input is ambiguous.
StableHLO
Lowers to stablehlo::hlo_tan().
Element-wise tangent.
(arrayish)
Arrayish value of data type floating-point.
arrayish
Has the same shape and data type as the input.
It is ambiguous if the input is ambiguous.
Lowers to stablehlo::hlo_tan().