Skip to contents

Sets the anvl.backend option for the duration of the expression. Every array built and every operation run in code uses the backend, and R values materialize at its default data types (see default_dtypes()).

Usage

with_backend(backend, code)

Arguments

backend

(character(1))
Backend to use ("pjrt" or "quickr").

code

An expression to evaluate with the given backend.

Value

(any)
The result of evaluating code.