Skip to contents

Computational graph consisting exclusively of primitive calls. This is a mutable class.

Usage

AnvlGraph(
  calls = list(),
  in_tree = NULL,
  out_tree = NULL,
  inputs = list(),
  outputs = list(),
  constants = list(),
  is_static_flat = NULL,
  static_args_flat = NULL
)

Arguments

calls

(list(PrimitiveCall))
The primitive calls that make up the graph.

in_tree

(NULL | Node)
The tree of inputs. May contain leaves for both array inputs and static (non-array) arguments. Only the array leaves correspond to entries in inputs; use is_static_flat to distinguish them.

out_tree

(NULL | Node)
The tree of outputs.

inputs

(list(GraphValue))
The inputs to the graph (array arguments only).

outputs

(list(GraphValue))
The outputs of the graph.

constants

(list(GraphValue))
The constants of the graph.

is_static_flat

(NULL | logical())
Boolean mask indicating which flat positions in in_tree are static (non-array) args. NULL when all args are array inputs.

static_args_flat

(NULL | list())
Flattened traced values for the static arguments indicated by is_static_flat.

Value

(AnvlGraph)