Block until the array's underlying computation has finished, and return the object invisibly. Useful for benchmarking, where the dispatch of an asynchronous operation should not be confused with its execution.
Arguments
- x
(
AnvlArrayor other awaitable)
An object with anawait()method.- ...
Additional arguments passed to methods (unused).
Details
Implemented via the generic pjrt::await(). For backends without
asynchronous execution (e.g. "quickr"), this is a no-op.
See also
pjrt::await(), map_tree() (to await a tree of outputs)