Pass the result to jit()'s device argument to indicate that the
device should be read from a formal argument of the function being
compiled. At call time, the value of that argument is used to derive the
backend via backend() dispatch and is forwarded to the backend-specific
JIT as the compilation device.
This is intended for functions that have no dynamic array inputs from which
the backend could otherwise be detected (e.g. array constructors like
prim_fill() or prim_iota()).
Arguments
- argname
(
character(1))
Name of a formal argument of the function passed tojit().
Value
(AnvlDeviceArg)
An object recognized by jit().