Convenience wrapper that JIT-compiles and immediately evaluates a single expression.
Equivalent to wrapping expr in an anonymous function, calling jit() on it, and
invoking the result.
Useful if you want to evaluate an expression once.
Arguments
- expr
(NSE)
Expression to compile and evaluate.- ...
Backend-specific options forwarded to
jit()(e.g.devicefor the"xla"backend,unwrapfor the"quickr"backend).