Skip to contents

Element-wise inverse hyperbolic cosine. You can also use acosh().

Usage

nv_acosh(x)

Arguments

x

(arrayish)
One input. Can be any numeric data type: a float keeps its own, and an integer one is converted to the default float data type (see default_dtypes()). An R value materializes at its default data type and is converted in the same way.

Value

(arrayish)
Has the input's shape, and its data type – or the default float data type (see default_dtypes()) where the input was an integer one.

See also

prim_acosh() for the underlying primitive.

Examples

# the input's data type carries through
x <- nv_array(c(1, 2, 10))
acosh(x)
#> AnvlArray
#>  0.0000
#>  1.3170
#>  2.9932
#> [ CPUf32{3} ] 

# an R value materializes at its default data type
nv_acosh(2)
#> AnvlArray
#>  1.3170
#> [ CPUf32{} ]