Adds two arrays element-wise.
You can also use the + operator.
Arguments
- lhs, rhs
(
arrayish)
Two inputs with a common data type. Can be any data type. Scalars are broadcast, and R values assume the other operand's data type within their data type category, otherwise falling back to their default data type and being converted to the common data type.
Value
(arrayish)
Has the inputs' broadcast shape and common data type.
See also
prim_add() for the underlying primitive.
Examples
x <- nv_array(c(1, 2, 3))
y <- nv_array(c(4, 5, 6))
nv_add(x, y)
#> AnvlArray
#> 5
#> 7
#> 9
#> [ CPUf32{3} ]
x + y
#> AnvlArray
#> 5
#> 7
#> 9
#> [ CPUf32{3} ]
# different data types are promoted to their common one
nv_add(nv_scalar(1, "f32"), nv_scalar(2, "f64"))
#> AnvlArray
#> 3
#> [ CPUf64{} ]
# a scalar is broadcast and an R integer is converted to a float
x + 1L
#> AnvlArray
#> 2
#> 3
#> 4
#> [ CPUf32{3} ]