Element-wise inverse sine. You can also use asin().
Arguments
- x
(
arrayish)
One input. Can be any numeric data type: a float keeps its own, and an integer one is converted to the default float data type (seedefault_dtypes()). An R value materializes at its default data type and is converted in the same way.
Value
(arrayish)
Has the input's shape, and its data type – or the default float data type
(see default_dtypes()) where the input was an integer one.
See also
prim_asin() for the underlying primitive.