Element-wise inverse sine. You can also use asin().
Arguments
- x
(
arrayish)
Input array.
Value
arrayish
Has the same shape and data type as the input.
See also
prim_asin() for the underlying primitive.
Element-wise inverse sine. You can also use asin().
(arrayish)
Input array.
arrayish
Has the same shape and data type as the input.
prim_asin() for the underlying primitive.