Element-wise inverse tangent. You can also use atan().
Arguments
- operand
(
arrayish)
Operand.
Value
arrayish
Has the same shape and data type as the input.
See also
prim_atan() for the underlying primitive.
Element-wise inverse tangent. You can also use atan().
(arrayish)
Operand.
arrayish
Has the same shape and data type as the input.
prim_atan() for the underlying primitive.