Element-wise inverse hyperbolic tangent. You can also use atanh().
Arguments
- operand
(
arrayish)
Operand.
Value
arrayish
Has the same shape and data type as the input.
See also
prim_atanh() for the underlying primitive.
Element-wise inverse hyperbolic tangent. You can also use atanh().
(arrayish)
Operand.
arrayish
Has the same shape and data type as the input.
prim_atanh() for the underlying primitive.