Broadcasts an array to a target shape, aligning the array's axes with the
leading axes of shape, so that a vector fills a column.
See nv_broadcast_arrays for more information.
Arguments
- x
(
arrayish)
One input. Can be any data type. An R value materializes at its default data type.- shape
(
integer())
Target shape. The input's axes are matched against its leading axes, and each must either match or be 1; trailing axes are added.
Value
(arrayish)
Has the given shape and the same data type as x.
See also
nv_broadcast_arrays(), nv_broadcast_scalars(),
prim_broadcast_in_axes() for the underlying primitive.