Broadcasts an array to a target shape using NumPy-style broadcasting rules.
Value
arrayish
Has the given shape and the same data type as operand.
See also
nv_broadcast_arrays(), nv_broadcast_scalars(),
prim_broadcast_in_dim() for the underlying primitive.