Concatenates arrays along an axis. Operands are promoted to a common data type and scalars are broadcast before concatenation.
Arguments
- ...
(
arrayish)
Arrays to concatenate. Must have the same shape except alongaxis.- axis
(
integer(1)|NULL)
Axis along which to concatenate. Negative values count from the end, i.e.-1refers to the last axis. IfNULL(default), assumes all inputs are at most 1-D and concatenates along axis 1.
Value
arrayish
Has the common data type and a shape matching the inputs in all
axes except axis, which is the sum of input sizes.
See also
prim_concatenate() for the underlying primitive.