Concatenates arrays along a dimension. Operands are promoted to a common data type and scalars are broadcast before concatenation.
Arguments
- ...
(
arrayish)
Arrays to concatenate. Must have the same shape except alongdimension.- dimension
(
integer(1)|NULL)
Dimension along which to concatenate. IfNULL(default), assumes all inputs are at most 1-D and concatenates along dimension 1.
Value
arrayish
Has the common data type and a shape matching the inputs in all
dimensions except dimension, which is the sum of input sizes.
See also
prim_concatenate() for the underlying primitive.