Converts the elements of an array to a different data type. Returns the input unchanged if it already has the target type.
Value
arrayish
Has the given dtype and the same shape as x.
See also
prim_convert() for the underlying primitive.
Converts the elements of an array to a different data type. Returns the input unchanged if it already has the target type.
arrayish
Has the given dtype and the same shape as x.
prim_convert() for the underlying primitive.