Converts the elements of an array to a different data type. Returns the input unchanged if it already has the target type.
Arguments
- operand
(
arrayish)
Operand.- dtype
(
character(1)|tengen::DataType)
Data type.
Value
arrayish
Has the given dtype and the same shape as operand.
See also
prim_convert() for the underlying primitive.