Element-wise cosine. You can also use cos().
Arguments
- x
(
arrayish)
Input array.
Value
arrayish
Has the same shape and data type as the input.
See also
prim_cos() for the underlying primitive.
Element-wise cosine. You can also use cos().
(arrayish)
Input array.
arrayish
Has the same shape and data type as the input.
prim_cos() for the underlying primitive.