Skip to contents

Element-wise hyperbolic cosine. You can also use cosh().

Usage

nv_cosh(x)

Arguments

x

(arrayish)
One input. Can be any numeric data type: a float keeps its own, and an integer one is converted to the default float data type (see default_dtypes()). An R value materializes at its default data type and is converted in the same way.

Value

(arrayish)
Has the input's shape, and its data type – or the default float data type (see default_dtypes()) where the input was an integer one.

See also

prim_cosh() for the underlying primitive.

Examples

# the input's data type carries through
x <- nv_array(c(-1, 0, 1))
cosh(x)
#> AnvlArray
#>  1.5431
#>  1.0000
#>  1.5431
#> [ CPUf32{3} ] 

# an R value materializes at its default data type
nv_cosh(1)
#> AnvlArray
#>  1.5431
#> [ CPUf32{} ]