Element-wise hyperbolic cosine. You can also use cosh().
Arguments
- x
(
arrayish)
Input array.
Value
arrayish
Has the same shape and data type as the input.
See also
prim_cosh() for the underlying primitive.
Element-wise hyperbolic cosine. You can also use cosh().
(arrayish)
Input array.
arrayish
Has the same shape and data type as the input.
prim_cosh() for the underlying primitive.