Computes the determinant of a square matrix via nv_determinant().
Arguments
- operand
(
arrayish)
Square matrix of floating-point data type.
Value
Scalar arrayish with the same dtype as operand.
Computes the determinant of a square matrix via nv_determinant().
(arrayish)
Square matrix of floating-point data type.
Scalar arrayish with the same dtype as operand.