Element-wise error function erf(x) = (2 / sqrt(pi)) * integral_0^x exp(-t^2) dt.
Arguments
- operand
(
arrayish)
Operand.
Value
arrayish
Has the same shape and data type as the input.
See also
prim_erf() for the underlying primitive.
Element-wise error function erf(x) = (2 / sqrt(pi)) * integral_0^x exp(-t^2) dt.
(arrayish)
Operand.
arrayish
Has the same shape and data type as the input.
prim_erf() for the underlying primitive.