Element-wise complementary error function erfc(x) = 1 - erf(x).
Arguments
- x
(
arrayish)
Input array.
Value
arrayish
Has the same shape and data type as the input.
See also
prim_erfc() for the underlying primitive.
Element-wise complementary error function erfc(x) = 1 - erf(x).
(arrayish)
Input array.
arrayish
Has the same shape and data type as the input.
prim_erfc() for the underlying primitive.