Element-wise exp(x) - 1, more accurate for small x.
Arguments
- operand
(
arrayish)
Operand.
Value
arrayish
Has the same shape and data type as the input.
See also
prim_expm1() for the underlying primitive.
Element-wise exp(x) - 1, more accurate for small x.
(arrayish)
Operand.
arrayish
Has the same shape and data type as the input.
prim_expm1() for the underlying primitive.