Flattens an array with one or more axes into a 1-D array, using col-major semantics.
Arguments
- x
(
arrayish)
One input. Can be any data type. An R value materializes at its default data type.
Value
(arrayish)
Has the input's data type, and one axis holding all of its elements –
so a scalar, which has none, becomes a length-1 vector.