Element-wise check if values are infinite (Inf or -Inf).
You can also use is.infinite().
Usage
nv_is_infinite(operand)
# S3 method for class 'AnvlBox'
is.infinite(x)Value
arrayish
Has the same shape as the input and boolean data type.
Element-wise check if values are infinite (Inf or -Inf).
You can also use is.infinite().
nv_is_infinite(operand)
# S3 method for class 'AnvlBox'
is.infinite(x)arrayish
Has the same shape as the input and boolean data type.