Element-wise check if values are NaN. You can also use is.nan().
Only a float holds a NaN, so the answer for any other data type is all
FALSE and is built as a constant rather than computed.
Arguments
- x
(
arrayish)
One input. Can be any data type. An R value materializes at its default data type.
Value
(arrayish)
Has the input's shape and boolean data type.