Element-wise natural logarithm of the absolute value of the gamma
function. You can also use lgamma().
Arguments
- operand
(
arrayish)
Operand.
Value
arrayish
Has the same shape and data type as the input.
See also
prim_lgamma() for the underlying primitive.