Element-wise natural logarithm. You can also use log().
Arguments
- x
(
arrayish)
Input array.
Value
arrayish
Has the same shape and data type as the input.
See also
prim_log() for the underlying primitive.
Element-wise natural logarithm. You can also use log().
(arrayish)
Input array.
arrayish
Has the same shape and data type as the input.
prim_log() for the underlying primitive.