Element-wise log(1 + x), more accurate for small x.
Arguments
- x
(
arrayish)
Input array.
Value
arrayish
Has the same shape and data type as the input.
See also
prim_log1p() for the underlying primitive.
Element-wise log(1 + x), more accurate for small x.
(arrayish)
Input array.
arrayish
Has the same shape and data type as the input.
prim_log1p() for the underlying primitive.