Element-wise log(1 + x), more accurate for small x.
Arguments
- operand
(
arrayish)
Operand.
Value
arrayish
Has the same shape and data type as the input.
See also
prim_log1p() for the underlying primitive.
Element-wise log(1 + x), more accurate for small x.
(arrayish)
Operand.
arrayish
Has the same shape and data type as the input.
prim_log1p() for the underlying primitive.