Matrix multiplication of two arrays. You can also use the %*% operator.
Supports batched matrix multiplication when inputs have more than 2 axes.
Arguments
- lhs, rhs
(
arrayish)
Numeric arrays with at least 2 axes. Can be any numeric data type; the two are promoted to a common data type. An R value assumes the data type of the other operand, and materializes at its default data type when that has none either.- precision
(
character(1))
Controls the trade-off between speed and numerical accuracy of the operation. One of"highest"(default),"high"or"default". Seeprim_dot_general()for details.
Value
(arrayish)
Has the operands' common data type and the shape given under Shapes.
See also
prim_dot_general() for the underlying primitive.