Matrix multiplication of two arrays. You can also use the %*% operator.
Supports batched matrix multiplication when inputs have more than 2 axes.
Arguments
- lhs, rhs
(
arrayish)
Arrays with at least 2 axes. Operands are promoted to a common data type.- precision
(
character(1))
Controls the trade-off between speed and numerical accuracy of the operation. One of"highest"(default),"high"or"default". Seeprim_dot_general()for details.
See also
prim_dot_general() for the underlying primitive.