Negates an array element-wise. You can also use the unary - operator.
Arguments
- x
(
arrayish)
Input array.
Value
arrayish
Has the same shape and data type as the input.
See also
prim_negate() for the underlying primitive.
Negates an array element-wise. You can also use the unary - operator.
(arrayish)
Input array.
arrayish
Has the same shape and data type as the input.
prim_negate() for the underlying primitive.