Element-wise logical NOT. You can also use the ! operator.
Arguments
- x
(
arrayish)
Input array.
Value
arrayish
Has the same shape and data type as the input.
See also
prim_not() for the underlying primitive.
Element-wise logical NOT. You can also use the ! operator.
(arrayish)
Input array.
arrayish
Has the same shape and data type as the input.
prim_not() for the underlying primitive.