Pads an array with a given value at the edges and optionally between elements.
Arguments
- x
(
arrayish)
Input array.- padding_value
(
arrayish)
Scalar value to use for padding. Must have the same dtype asx.- edge_padding_low
(
integer())
Amount of padding to add at the start of each axis.- edge_padding_high
(
integer())
Amount of padding to add at the end of each axis.- interior_padding
(
integer()|NULL)
Amount of padding to add between elements in each axis. IfNULL(default), no interior padding is applied.
Value
arrayish
Has the same data type as x.
See also
prim_pad() for the underlying primitive.