Prints an array value to the console during JIT execution and returns the input unchanged. Useful for debugging.
Arguments
- x
(
arrayish)
Input array.
Value
arrayish
Returns x unchanged.
See also
prim_print() for the underlying primitive.
Prints an array value to the console during JIT execution and returns the input unchanged. Useful for debugging.
(arrayish)
Input array.
arrayish
Returns x unchanged.
prim_print() for the underlying primitive.