Skip to contents

Loads arrays from a file in the safetensors format.

Usage

nv_read(path, device = NULL)

Arguments

path

(character(1))
Path to the safetensors file.

device

(NULL | character(1) | PJRTDevice)
The device on which to place the loaded arrays ("cpu", "cuda", ...). Defaults to default_device() of the "pjrt" backend, which the loader goes through whatever the active backend is.

Value

(named list of AnvlArray)

Details

This is a convenience wrapper around nv_unserialize() that opens and closes a file connection.

Examples

# data types and shapes round-trip unchanged
x <- nv_matrix(1:6, nrow = 2)
x
#> AnvlArray
#>  1 3 5
#>  2 4 6
#> [ CPUi32{2,3} ] 
path <- tempfile(fileext = ".safetensors")
nv_save(list(x = x), path)
nv_read(path)
#> $x
#> AnvlArray
#>  1 3 5
#>  2 4 6
#> [ CPUi32{2,3} ] 
#>