Loads arrays from a file in the safetensors format.
Arguments
- path
(
character(1))
Path to the safetensors file.- device
(
NULL|character(1)|PJRTDevice)
The device on which to place the loaded arrays ("cpu","cuda", ...). Defaults todefault_device()of the"pjrt"backend, which the loader goes through whatever the active backend is.
Value
(named list of AnvlArray)
Details
This is a convenience wrapper around nv_unserialize() that opens and
closes a file connection.