Loads arrays from a file in the safetensors format.
Usage
nv_read(path, device = NULL, backend = default_backend())Arguments
- path
(
character(1))
Path to the safetensors file.- device
(
NULL|character(1)|PJRTDevice)
The device on which to place the loaded arrays ("cpu","cuda", ...). Default is to use the CPU.- backend
(
character(1))
Backend for the loaded arrays. Defaults todefault_backend().
Value
Named list of AnvlArray objects.
Details
This is a convenience wrapper around nv_unserialize() that opens and
closes a file connection.