Reverses the order of elements along specified axes.
Value
arrayish
Has the same shape and data type as x.
See also
prim_reverse() for the underlying primitive.
Reverses the order of elements along specified axes.
arrayish
Has the same shape and data type as x.
prim_reverse() for the underlying primitive.