Element-wise sign function. You can also use sign().
Arguments
- x
(
arrayish)
Input array.
Value
arrayish
Has the same shape and data type as the input.
See also
prim_sign() for the underlying primitive.
Element-wise sign function. You can also use sign().
(arrayish)
Input array.
arrayish
Has the same shape and data type as the input.
prim_sign() for the underlying primitive.