Element-wise square root. You can also use sqrt().
Arguments
- x
(
arrayish)
Input array.
Value
arrayish
Has the same shape and data type as the input.
See also
prim_sqrt() for the underlying primitive.
Element-wise square root. You can also use sqrt().
(arrayish)
Input array.
arrayish
Has the same shape and data type as the input.
prim_sqrt() for the underlying primitive.