Removes axes of size 1 from an array.
Arguments
- x
(
arrayish)
One input. Can be any data type. An R value materializes at its default data type.- axes
(
integer()|NULL)
Axes to squeeze. Negative values count from the end, i.e.-1refers to the last axis. IfNULL(default), all axes of size 1 are removed.
Value
(arrayish)
Has x's data type, with the specified axes removed from its shape.