Updates elements of an array at specified positions, returning a new array.
You can also use the [<- operator.
Arguments
- x
(
arrayish)
Same asoperand; this is the name used by the base R S3 generic.- ...
Subset specifications, one per dimension. See
vignette("subsetting")for details.- value
(
arrayish)
Replacement values. Scalars are broadcast to the subset shape. Non-scalar values must match the subset shape.- operand
(
arrayish)
Operand.
Value
arrayish
A new array with the same shape as operand and the subset replaced.
See also
nv_subset(), vignette("subsetting") for a comprehensive guide.