Updates elements of an array at specified positions, returning a new array.
You can also use the [<- operator.
Arguments
- x
(
arrayish)
The array to update. Can be any data type. An R object is materialized at its default data type.- ...
Subset specifications, one per axis. See
vignette("subsetting")for details.- value
(
arrayish)
Replacement values. Scalars are broadcast to the subset shape and non-scalar values must match it. The value is converted to the data type ofx.
Value
(arrayish)
Has x's data type and shape, with the subset replaced.
See also
nv_subset(), vignette("subsetting") for a comprehensive guide.