Skip to contents

Element-wise tangent. You can also use tan().

Usage

nv_tan(x)

Arguments

x

(arrayish)
One input. Can be any numeric data type: a float keeps its own, and an integer one is converted to the default float data type (see default_dtypes()). An R value materializes at its default data type and is converted in the same way.

Value

(arrayish)
Has the input's shape, and its data type – or the default float data type (see default_dtypes()) where the input was an integer one.

See also

prim_tan() for the underlying primitive.

Examples

# the input's data type carries through
x <- nv_array(c(0, 0.5, 1))
tan(x)
#> AnvlArray
#>  0.0000
#>  0.5463
#>  1.5574
#> [ CPUf32{3} ] 

# an R value materializes at its default data type
nv_tan(0.5)
#> AnvlArray
#>  0.5463
#> [ CPUf32{} ]