Element-wise tangent. You can also use tan().
Arguments
- x
(
arrayish)
Input array.
Value
arrayish
Has the same shape and data type as the input.
See also
prim_tan() for the underlying primitive.
Element-wise tangent. You can also use tan().
(arrayish)
Input array.
arrayish
Has the same shape and data type as the input.
prim_tan() for the underlying primitive.