Element-wise hyperbolic tangent. You can also use tanh().
Arguments
- x
(
arrayish)
Input array.
Value
arrayish
Has the same shape and data type as the input.
See also
prim_tanh() for the underlying primitive.
Element-wise hyperbolic tangent. You can also use tanh().
(arrayish)
Input array.
arrayish
Has the same shape and data type as the input.
prim_tanh() for the underlying primitive.