Returns the lower triangular part of a 2-D array, setting elements above the specified diagonal to zero.
Arguments
- operand
(
arrayish)
Operand.- diagonal
(
integer(1))
Diagonal offset.0(default) is the main diagonal, positive values include diagonals above, negative values exclude diagonals below.
Value
arrayish
Has the same shape and data type as operand.