The data type x would take if it was converted to an AnvlArray.
Relevant for R objects and their RData trace-time analogon: for those it
is the default of the active backend (see default_dtypes()), which the
value has not materialized at yet.
Arguments
- x
(
arrayish|AbstractArray)
The value to ask about.
Value
(tengen::DataType)
The data type x has, or the default data type it would
materialize at if it is still a bare R value.
Examples
peek_dtype(1.5)
#> <f32>
peek_dtype(1L)
#> <i32>
peek_dtype(nv_array(1:3, dtype = "i8"))
#> <i8>