Returns the index of the minimum value along a single axis. Ties are broken by returning the smallest index.
Arguments
- x
(
arrayish)
Arrayish value of any data type.- axis
(
integer(1))
Axis along which to find the index of the maximum. Negative values count from the end, i.e.-1refers to the last axis.- drop
(
logical(1))
IfTRUE(default) the reduced axis is removed; ifFALSEit is kept with size 1.
Value
arrayish of dtype i32
Same shape as x with axis removed (or set to 1 if
drop = FALSE).
StableHLO
Lowers to a variadic hlo_reduce() over (values, indices)
with a (value < value | (value == value & idx < idx)) selector.