Element-wise atan2 operation.
Arguments
- lhs, rhs
(
arrayish)
Two inputs of the same data type and shape. Can be any float data type. R values assume the other operand's data type when it is in their data type category, and their default data type when neither operand has one.
Value
(arrayish)
Has the inputs' shape and data type.
StableHLO
Lowers to hlo_atan2(), specified under
atan2.
Examples
# two R values: both take an R double's default data type
prim_atan2(1, 1)
#> AnvlArray
#> 0.7854
#> [ CPUf32{} ]
# the R value is built at the array's data type instead
prim_atan2(1, nv_scalar(1, "f64"))
#> AnvlArray
#> 0.7854
#> [ CPUf64{} ]