Reinterprets the bits of an array as a different data type without modifying the underlying data.
Value
arrayish
Has the given dtype.
StableHLO
Lowers to hlo_bitcast_convert().
Reinterprets the bits of an array as a different data type without modifying the underlying data.
arrayish
Has the given dtype.
Lowers to hlo_bitcast_convert().