Reinterprets the bits of an array as a different data type without modifying the underlying data.
Arguments
- operand
(
arrayish)
Arrayish value of any data type.- dtype
(
character(1)|tengen::DataType)
Target data type. If it has the same bit width as the input, the output shape is unchanged. If narrower, an extra trailing dimension is added. If wider, the last dimension is consumed.
Value
arrayish
Has the given dtype.
StableHLO
Lowers to stablehlo::hlo_bitcast_convert().