Computes the Cholesky decomposition of a symmetric positive-definite matrix. Axes before the last two are batch axes.
Arguments
- x
(
arrayish)
Arrayish value of data type floating-point with at least 2 axes. The last two axes must be equal (square matrix); any leading axes are batch axes.- lower
(
logical(1))
IfFALSE(default, matching base R'sbase::chol()), compute the upper triangular factorUsuch thatx = t(U) %*% U. IfTRUE, compute the lower triangular factorLsuch thatx = L %*% t(L).
Value
arrayish
Has the same shape and data type as the input.
The values in the triangle not specified by lower are implementation-defined.
It is ambiguous if the input is ambiguous.
StableHLO
Lowers to hlo_cholesky().
References
Murray I (2016). “Differentiation of the Cholesky decomposition.” arXiv preprint arXiv:1602.07527.
Walter S (2012). Structured higher-order algorithmic differentiation in the forward and reverse mode with application in optimum experimental design. Ph.D. thesis, Mathematisch-Naturwissenschaftliche Fakult"at II.