Concatenates arrays along an axis.
Arguments
- ...
(
arrayish)
Arrays to concatenate. Must all have the same data type, naxes, and shape except alongaxis.- axis
(
integer(1))
Axis along which to concatenate. Negative values count from the end, i.e.-1refers to the last axis.
Value
arrayish
Has the same data type as the inputs.
The output shape matches the inputs in all axes except axis,
which is the sum of the input sizes along that axis.
It is ambiguous if all inputs are ambiguous.
StableHLO
Lowers to hlo_concatenate().