Element-wise check if values are finite (not Inf, -Inf, or NaN).
Arguments
- x
(
arrayish)
One input. Can be any float data type. An R value materializes at its default data type.
Value
(arrayish)
Has the same shape as the input and boolean data type.
StableHLO
Lowers to hlo_is_finite(), specified under
is_finite.