Element-wise natural logarithm of the absolute value of the gamma function.
Arguments
- x
(
arrayish)
One input. Can be any float data type. An R value materializes at its default data type.
Value
(arrayish)
Has the input's shape and data type.
StableHLO
Lowers to hlo_lgamma(), an op of the CHLO dialect, a higher-level
companion to StableHLO that is lowered to it during compilation. See
chlo.lgamma.