Element-wise maximum of two arrays.
Arguments
- lhs, rhs
(
arrayish)
Two inputs of the same data type and shape. Can be any data type. R values assume the other operand's data type when it is in their data type category, and their default data type when neither operand has one.
Value
(arrayish)
Has the inputs' shape and data type.
StableHLO
Lowers to hlo_maximum(), specified under
maximum.
Examples
# two R values: both take an R double's default data type
prim_max(1, 5)
#> AnvlArray
#> 5
#> [ CPUf32{} ]
# the R value is built at the array's data type instead
prim_max(1, nv_scalar(5, "f64"))
#> AnvlArray
#> 5
#> [ CPUf64{} ]