Element-wise logical NOT.
Arguments
- operand
(
arrayish)
Arrayish value of data type boolean, integer, or unsigned integer.
Value
arrayish
Has the same shape and data type as the input.
It is ambiguous if the input is ambiguous.
StableHLO
Lowers to stablehlo::hlo_not().