Pads an array with a given padding value.
Arguments
- x
(
arrayish)
Arrayish value of any data type.- padding_value
(
arrayish)
Scalar value to use for padding. Must have the same dtype asx.- edge_padding_low
(
integer())
Amount of padding to add at the start of each axis.- edge_padding_high
(
integer())
Amount of padding to add at the end of each axis.- interior_padding
(
integer())
Amount of padding to add between elements in each axis.
Value
arrayish
Has the same data type as x.
For the output shape see the underlying stablehlo documentation (hlo_pad()).
It is ambiguous if the input is ambiguous.
StableHLO
Lowers to hlo_pad().