Element-wise polygamma function: the (n+1)-th derivative of the
log-gamma function. Both n and x must have the same shape; n
typically holds non-negative integer values.
Arguments
- n, x
(
arrayish)
Arrayish values of data type floating-point. Must have the same shape.
Value
arrayish
Has the same shape and data type as the inputs.
It is ambiguous if both inputs are ambiguous.
StableHLO
Lowers to stablehlo::hlo_polygamma().