Element-wise polygamma function: the (n+1)-th derivative of the
log-gamma function. Both n and x must have the same shape; n
typically holds non-negative integer values.
Arguments
- n, x
(
arrayish)
Two inputs of the same shape. Can be any float data type.nandxmust have the same data type. An R value among them assumes the data type of the others when it is in its data type category, and its default data type when none of them has one.
Value
(arrayish)
Has the inputs' shape and data type.
StableHLO
Lowers to hlo_polygamma(), an op of the CHLO dialect, a higher-level
companion to StableHLO that is lowered to it during compilation. See
chlo.polygamma.