Element-wise population count (number of set bits).
Arguments
- operand
(
arrayish)
Arrayish value of data type integer or unsigned integer.
Value
arrayish
Has the same shape and data type as the input.
It is ambiguous if the input is ambiguous.
StableHLO
Lowers to stablehlo::hlo_popcnt().