Raises lhs to the power of rhs element-wise.
Arguments
- lhs, rhs
(
arrayish)
Two inputs of the same data type and shape. Can be any numeric data type. R values assume the other operand's data type when it is in their data type category, and their default data type when neither operand has one.
Value
(arrayish)
Has the inputs' shape and data type.
StableHLO
Lowers to hlo_power(), specified under
power.
See also
nv_pow(), ^
Examples
# two R values: both take an R double's default data type
prim_pow(2, 3)
#> AnvlArray
#> 8
#> [ CPUf32{} ]
# the R value is built at the array's data type instead
prim_pow(2, nv_scalar(3, "f64"))
#> AnvlArray
#> 8
#> [ CPUf64{} ]