Skip to contents

Element-wise remainder of division.

Usage

prim_remainder(lhs, rhs)

Arguments

lhs, rhs

(arrayish)
Arrayish values of data type integer, unsigned integer, or floating-point. Must have the same shape.

Value

arrayish
Has the same shape and data type as the inputs. It is ambiguous if both inputs are ambiguous.

Implemented Rules

  • stablehlo

  • reverse

StableHLO

Lowers to stablehlo::hlo_remainder().

See also

Examples

x <- nv_array(c(7, 10, 15))
y <- nv_array(c(3, 4, 6))
prim_remainder(x, y)
#> AnvlArray
#>  1
#>  2
#>  3
#> [ CPUf32{3} ]