Reverses the order of elements along specified axes.
Value
arrayish
Has the same data type and shape as x.
It is ambiguous if the input is ambiguous.
StableHLO
Lowers to hlo_reverse().
Reverses the order of elements along specified axes.
arrayish
Has the same data type and shape as x.
It is ambiguous if the input is ambiguous.
Lowers to hlo_reverse().