Rounds the elements of an array to the nearest integer.
Arguments
- x
(
arrayish)
One input. Can be any float data type. An R value materializes at its default data type.- method
(
character(1))
Rounding method."nearest_even"(default) rounds to the nearest even integer on a tie,"afz"rounds away from zero on a tie.
Value
(arrayish)
Has x's data type and shape.
StableHLO
Lowers to hlo_round_nearest_even(), specified under
round_nearest_even.
With method = "afz" it lowers to hlo_round_nearest_afz() instead,
specified under
round_nearest_afz.