Rounds the elements of an array to the nearest integer.
Arguments
- x
(
arrayish)
Arrayish value of data type floating-point.- method
(
character(1))
Rounding method."nearest_even"(default) rounds to the nearest even integer on a tie,"afz"rounds away from zero on a tie.
Value
arrayish
Has the same dtype and shape as x.
It is ambiguous if the input is ambiguous.
StableHLO
Lowers to hlo_round_nearest_even() or
hlo_round_nearest_afz() depending on the method parameter.