Skip to contents

Element-wise arithmetic right bit shift.

Usage

prim_shift_right_arithmetic(lhs, rhs)

Arguments

lhs, rhs

(arrayish)
Arrayish values of data type boolean, integer, or unsigned integer. Must have the same shape.

Value

arrayish
Has the same shape and data type as the inputs. It is ambiguous if both inputs are ambiguous.

Implemented Rules

  • stablehlo

  • reverse

Examples

x <- nv_array(c(8L, -16L, 32L))
y <- nv_array(c(1L, 2L, 3L))
prim_shift_right_arithmetic(x, y)
#> AnvlArray
#>   4
#>  -4
#>   4
#> [ CPUi32{3} ]