Element-wise sign.
Arguments
- x
(
arrayish)
Arrayish value of data type signed integer or floating-point.
Value
arrayish
Has the same shape and data type as the input.
It is ambiguous if the input is ambiguous.
StableHLO
Lowers to hlo_sign().
Element-wise sign.
(arrayish)
Arrayish value of data type signed integer or floating-point.
arrayish
Has the same shape and data type as the input.
It is ambiguous if the input is ambiguous.
Lowers to hlo_sign().