Element-wise hyperbolic sine.
Arguments
- x
(
arrayish)
Arrayish value of data type floating-point.
Value
arrayish
Has the same shape and data type as the input.
It is ambiguous if the input is ambiguous.
StableHLO
Lowers to hlo_sinh().
Element-wise hyperbolic sine.
(arrayish)
Arrayish value of data type floating-point.
arrayish
Has the same shape and data type as the input.
It is ambiguous if the input is ambiguous.
Lowers to hlo_sinh().