Permutes the axes of an array.
Value
arrayish
Has the same data type as the input and shape nv_shape(x)[permutation].
It is ambiguous if the input is ambiguous.
StableHLO
Lowers to hlo_transpose().
Permutes the axes of an array.
arrayish
Has the same data type as the input and shape nv_shape(x)[permutation].
It is ambiguous if the input is ambiguous.
Lowers to hlo_transpose().