Permutes the dimensions of an array.
Value
arrayish
Has the same data type as the input and shape nv_shape(operand)[permutation].
It is ambiguous if the input is ambiguous.
StableHLO
Lowers to stablehlo::hlo_transpose().
Permutes the dimensions of an array.
arrayish
Has the same data type as the input and shape nv_shape(operand)[permutation].
It is ambiguous if the input is ambiguous.
Lowers to stablehlo::hlo_transpose().