Sets the anvl.backend option for the duration of the expression. Every
array built and every operation run in code uses the backend, and R values
materialize at its default data types (see default_dtypes()).
Sets the anvl.backend option for the duration of the expression. Every
array built and every operation run in code uses the backend, and R values
materialize at its default data types (see default_dtypes()).